@@ -9,6 +9,7 @@ from django.utils.importlib import import_module
 from django_jenkins import signals
 from django_jenkins.runner import CITestSuiteRunner
 
+
 def get_runner():
     if hasattr(settings, 'JENKINS_TEST_RUNNER'):
         test_path = settings.JENKINS_TEST_RUNNER.split('.')
@@ -21,7 +22,8 @@ def get_runner():
         test_runner = getattr(test_module, test_path[-1])
 
         if not issubclass(test_runner, CITestSuiteRunner):
-            raise ValueError('Your custom TestRunner should extend the CITestSuiteRunner class.')
+            raise ValueError('Your custom TestRunner should extend '
+                             'the CITestSuiteRunner class.')
         return test_runner
     else:
         return CITestSuiteRunner
@@ -31,15 +33,21 @@ class TaskListCommand(BaseCommand):
     """
     Run list of predifined tasks from command line
     """
-    requires_model_validation = False  # if True, breaks coverage of models.py files
+    requires_model_validation = False  # if True, breaks coverage
+                                       # of models.py files
 
     option_list = BaseCommand.option_list + (
-        make_option('--all', action='store_true', dest='test_all', default=False,
-            help='Ignore PROJECT_APPS settings and run through all INSTALLED_APPS'),
-        make_option('--interactive', action='store_true', dest='interactive', default=False,
+        make_option('--all', action='store_true',
+                    dest='test_all', default=False,
+            help='Ignore PROJECT_APPS settings and run '
+                 'through all INSTALLED_APPS'),
+        make_option('--interactive', action='store_true',
+                    dest='interactive', default=False,
             help='Allow to ask user input'),
-        make_option('--debug', action='store_true', dest='debug', default=False,
-            help='Do not intercept stdout and stderr, friendly for console debuggers'),
+        make_option('--debug', action='store_true',
+                    dest='debug', default=False,
+            help='Do not intercept stdout and stderr, '
+                 'friendly for console debuggers'),
         make_option('--output-dir', dest='output_dir', default="reports",
             help='Report files directory'),
         make_option('--liveserver',
@@ -51,19 +59,23 @@ class TaskListCommand(BaseCommand):
 
     def __init__(self):
         super(TaskListCommand, self).__init__()
-        self.tasks_cls = [import_module(module_name).Task for module_name in self.get_task_list()]
+        self.tasks_cls = [import_module(module_name).Task
+                                for module_name in self.get_task_list()]
 
     def handle(self, *test_labels, **options):
         # options
         if options.get('liveserver') is not None:
-            os.environ['DJANGO_LIVE_TEST_SERVER_ADDRESS'] = options['liveserver']
+            os.environ['DJANGO_LIVE_TEST_SERVER_ADDRESS'] = \
+                                                        options['liveserver']
             del options['liveserver']
 
         # instantiate tasks
         self.tasks = self.get_tasks(*test_labels, **options)
 
         # subscribe
-        for signal_name, signal in inspect.getmembers(signals, predicate=lambda obj: obj):
+        for signal_name, signal in inspect.getmembers(
+                                                signals,
+                                                predicate=lambda obj: obj):
             for task in self.tasks:
                 signal_handler = getattr(task, signal_name, None)
                 if signal_handler:
