@@ -7,7 +7,8 @@ class Command(TaskListCommand):
     help = "Run pyflakes over project apps"
     args = '[appname ...]'
     option_list = TaskListCommand.option_list + (
-        make_option('--pyflakes-file-output', action='store_true', dest='pyflakes_file_output', default=False,
+        make_option('--pyflakes-file-output', action='store_true',
+                     dest='pyflakes_file_output', default=False,
             help='Store pep8 report in file'),
     )
 
