@@ -6,11 +6,22 @@ from itertools import groupby
 from xml.sax.saxutils import XMLGenerator
 from xml.sax.xmlreader import AttributesImpl
 from django.conf import settings
-from django.test.simple import DjangoTestSuiteRunner, reorder_suite
-from django.utils.unittest import TestSuite, TestCase, TextTestResult, TextTestRunner
+from django.test.simple import DjangoTestSuiteRunner
+from django.test.testcases import TestCase
+from django.utils.unittest import TestSuite, TextTestResult, TextTestRunner
 from django_jenkins import signals
 from django_jenkins.functions import total_seconds
 
+try:
+    from django.test.simple import reorder_suite
+except ImportError:
+    from django.test.runner import reorder_suite
+
+try:
+    from django.utils.encoding import smart_text
+except ImportError:
+    from django.utils.encoding import smart_unicode as smart_text
+
 
 STDOUT_LINE = '\nStdout:\n%s'
 STDERR_LINE = '\nStderr:\n%s'
@@ -31,7 +42,7 @@ class TestInfo(object):
     def __init__(self, **kwargs):
         for slot_name in self.__slots__:
             setattr(self, slot_name, None)
-        for key, value in kwargs.iteritems():
+        for key, value in kwargs.items():
             setattr(self, key, value)
 
 
@@ -54,7 +65,8 @@ class XMLTestResult(TextTestResult):
         """
         Called when the given test is about to be run
         """
-        self.currentTestInfo = TestInfo(test_method=test, start_time=datetime.now())
+        self.currentTestInfo = TestInfo(test_method=test,
+                                        start_time=datetime.now())
         super(XMLTestResult, self).startTest(test)
 
     def stopTest(self, test):
@@ -136,16 +148,18 @@ class XMLTestResult(TextTestResult):
             msgLines = traceback.format_exception(exctype, value, tb)
 
         if self.buffer:
-            output = self._stdout_buffer.getvalue()
-            error = self._stderr_buffer.getvalue()
-            if output:
-                if not output.endswith('\n'):
-                    output += '\n'
-                msgLines.append(STDOUT_LINE % output)
-            if error:
-                if not error.endswith('\n'):
-                    error += '\n'
-                msgLines.append(STDERR_LINE % error)
+            if self._stdout_buffer:
+                output = self._stdout_buffer.getvalue()
+                if output:
+                    if not output.endswith('\n'):
+                        output += '\n'
+                    msgLines.append(STDOUT_LINE % output)
+            if self._stderr_buffer:
+                error = self._stderr_buffer.getvalue()
+                if error:
+                    if not error.endswith('\n'):
+                        error += '\n'
+                    msgLines.append(STDERR_LINE % error)
         return ''.join(msgLines)
 
     def test_method_name(self, test):
@@ -171,37 +185,47 @@ class XMLTestResult(TextTestResult):
         """
         self.buffer = False
 
-        with open(os.path.join(output_dir, 'junit.xml'), 'w') as output:            
+        if not os.path.exists(output_dir):
+            os.makedirs(output_dir)
+
+        with open(os.path.join(output_dir, 'junit.xml'), 'w') as output:
             document = XMLGenerator(output, 'utf-8')
             document.startDocument()
             document.startElement('testsuites', AttributesImpl({}))
 
-            suites = groupby(self.testInfos, key=lambda test_info: self.test_case_name(test_info.test_method))
+            suites = groupby(self.testInfos,
+                             key=lambda test_info: self.test_case_name(
+                                                        test_info.test_method))
             for suite_name, suite in suites:
-                document.startElement('testsuite', AttributesImpl({'name' : suite_name}))
+                document.startElement('testsuite',
+                                      AttributesImpl({'name': suite_name}))
 
                 for test_info in suite:
                     document.startElement('testcase', AttributesImpl({
-                        'classname' : suite_name,
-                        'name' : self.test_method_name(test_info.test_method),
-                        'time' : '%3f' % total_seconds(test_info.end_time - test_info.start_time)
+                        'classname': suite_name,
+                        'name': self.test_method_name(test_info.test_method),
+                        'time': '%3f' % total_seconds(
+                                    test_info.end_time - test_info.start_time)
                     }))
 
                     if test_info.result == TestInfo.RESULT.ERROR:
                         document.startElement('error', AttributesImpl({
-                            'message' : unicode(test_info.err[1])
+                            'message': smart_text(test_info.err[1])
                         }))
-                        document.characters(self._exc_info_to_string(test_info.err, test_info.test_method))
+                        document.characters(self._exc_info_to_string(
+                                        test_info.err, test_info.test_method))
                         document.endElement('error')
                     elif test_info.result == TestInfo.RESULT.FAILURE:
                         document.startElement('failure', AttributesImpl({
-                            'message' : unicode(test_info.err[1])
+                            'message': smart_text(test_info.err[1])
                         }))
-                        document.characters(self._exc_info_to_string(test_info.err, test_info.test_method))
+                        document.characters(self._exc_info_to_string(
+                                        test_info.err, test_info.test_method))
                         document.endElement('failure')
-                    elif test_info.result == TestInfo.RESULT.UNEXPECTED_SUCCESS:
+                    elif test_info.result == \
+                                    TestInfo.RESULT.UNEXPECTED_SUCCESS:
                         document.startElement('error', AttributesImpl({
-                            'message' : 'Unexpected success'
+                            'message': 'Unexpected success'
                         }))
                         document.endElement('error')
                     elif test_info.result == TestInfo.RESULT.SKIPPED:
@@ -245,7 +269,9 @@ class CITestSuiteRunner(DjangoTestSuiteRunner):
 
     def setup_databases(self):
         if 'south' in settings.INSTALLED_APPS:
-            from south.management.commands import patch_for_test_db_setup  # pylint: disable=F0401
+            from south.management.commands import (
+                    patch_for_test_db_setup  # pylint: disable=F0401
+                    )
             patch_for_test_db_setup()
         return super(CITestSuiteRunner, self).setup_databases()
 
@@ -256,7 +282,10 @@ class CITestSuiteRunner(DjangoTestSuiteRunner):
 
     def run_suite(self, suite, **kwargs):
         signals.before_suite_run.send(sender=self)
-        result = TextTestRunner(buffer=True, resultclass=XMLTestResult).run(suite)
+        result = TextTestRunner(buffer=True,
+                resultclass=XMLTestResult,
+                verbosity=self.verbosity
+                ).run(suite)
         if self.with_reports:
             result.dump_xml(self.output_dir)
         signals.after_suite_run.send(sender=self)
