@@ -15,7 +15,8 @@ class Task(BaseTask):
         super(Task, self).__init__(test_labels, options)
         if not self.test_labels:
             if hasattr(settings, 'PROJECT_APPS') and not options['test_all']:
-                self.test_labels = [app_name.split('.')[-1] for app_name in settings.PROJECT_APPS]
+                self.test_labels = [app_name.split('.')[-1]
+                                        for app_name in settings.PROJECT_APPS]
 
     def build_suite(self, suite, **kwargs):
         if self.test_labels:
